pub struct BlockStatus {
pub tokens: u64,
pub cost: f64,
pub cache_read: u64,
pub pct_of_limit: Option<f64>,
pub resets_at: Option<String>,
pub secs_until_reset: Option<i64>,
pub elapsed_hr: Option<f64>,
pub burn_cost_per_hr: Option<f64>,
pub burn_tokens_per_min: Option<f64>,
pub projected_cost: Option<f64>,
pub eta_to_limit_secs: Option<i64>,
}Expand description
Burn snapshot for one agent’s active 5h window.
Fields
tokens: u64cost: f64cache_read: u64pct_of_limit: Option<f64>Account utilization % of the 5h limit (from the usage API / statusline).
resets_at: Option<String>secs_until_reset: Option<i64>Seconds until the window frees (clamped ≥ 0).
elapsed_hr: Option<f64>Hours elapsed since the window’s oldest turn (0..=5).
burn_cost_per_hr: Option<f64>Spend rate over the elapsed window, USD/hour.
burn_tokens_per_min: Option<f64>Token rate over the elapsed window, tokens/minute.
projected_cost: Option<f64>Projected window cost if the current rate holds to window end.
eta_to_limit_secs: Option<i64>Seconds until the account limit is hit at the current %/hour, if known.